# ../scripts/custom/gg_knifenade/gg_knifenade.py

# =============================================================================
# >> IMPORTS
# =============================================================================
# EventScripts Imports
#   Gamethread
from gamethread import delayed

# GunGame Imports
#   Addons
from gungame51.core.addons.info import AddonInfo
#   Players
from gungame51.core.players.shortcuts import add_attribute_callback
from gungame51.core.players.shortcuts import remove_callbacks_for_addon
#   Weapons
from gungame51.core.weapons.shortcuts import get_level_weapon

# Script Imports
from modules.bonuses import knifenade
from modules.smoke import smoke

# =============================================================================
# >> ADDON REGISTRATION/INFORMATION
# =============================================================================
info = AddonInfo()
info.name = 'gg_knifenade'
info.title = 'GG Knife Nade Bonus'
info.author = 'Satoon101'
info.version = '1.0'


# =============================================================================
# >> LOAD & UNLOAD
# =============================================================================
def load():
    '''Called when the script is loaded'''

    # Register the level attribute callback
    add_attribute_callback('level', level_callback, info.name)

    # Refresh the precached model for the smoke
    smoke.refresh_precache()


def unload():
    '''Called when the script is unloaded'''

    # Unregister the level attribute callbacks
    remove_callbacks_for_addon(info.name)

    # Clear the players from the dictionary
    knifenade.clear()


# =============================================================================
# >> ATTRIBUTE CALLBACKS
# =============================================================================
def level_callback(name, level, ggPlayer):
    '''Called when the given player's level is being changed'''

    # Check to see if the player had bonuses that need removed
    knifenade.check_remove_bonuses(ggPlayer.userid)

    # Delay 1 tick, then check to see if the player needs new bonuses
    delayed(0, knifenade.check_bonuses, ggPlayer.userid)


# =============================================================================
# >> GAME EVENTS
# =============================================================================
def es_map_start(event_var):
    '''Called every time a map is loaded'''

    # Refresh the precached model for the smoke
    smoke.refresh_precache()

    # Clear the players from the dictionary
    knifenade.clear()


def cs_win_panel_match(event_var):
    '''Called when the map ends'''

    # Clear the players from the dictionary
    knifenade.clear()


def player_spawn(event_var):
    '''Called any time a player spawns'''

    # Check to see if the player needs to receive bonuses
    knifenade.check_spawn_bonuses(event_var['userid'])


def gg_win(event_var):
    '''Called when a player wins the match'''

    # Clear the players from the dictionary
    knifenade.clear()


def gg_team_win(event_var):
    '''Called when a team wins the match'''

    # Clear the players from the dictionary
    knifenade.clear()
