# ../scripts/custom/gg_knifenade/gg_knifenade_config.py

# =============================================================================
# >> IMPORTS
# =============================================================================
# Python Imports
from __future__ import with_statement
from path import path

# GunGame Imports
from gungame51.core.cfg.configs import ConfigContextManager


# =============================================================================
# >> LOAD & UNLOAD
# =============================================================================
def load():

    # Create the cfg file
    with ConfigContextManager(
      path(__file__).parent.split('scripts')[~0][1:]) as config:

        # Create the gg_knifenade instance
        with config.cfg_cvar('gg_knifenade') as cvar:

            cvar.name = 'KNIFE NADE BONUS'
            cvar.description.append(
                'Gives players bonuses when on knife/nade level.')
            cvar.options.append(
                '0 = (Disabled) Do not load gg_knifenade.')
            cvar.options.append('1 = (Enabled) Load gg_knifenade.')
            cvar.default = 0
            cvar.text = 'Enables/Disables gg_knifenade.'

        # Loop through hegrenade and knife
        for weapon in ('HEGrenade', 'Knife'):

            # Create the weapon's section
            config.cfg_section('%s SETTINGS' % weapon.upper())

            # Create the weapon's "smoke" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_smoke' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL SMOKE' % weapon.upper()
                cvar.description.append('If enabled, %s ' % weapon +
                    'players will be given a smoke grenade.')
                cvar.options.append(
                    '0 = Do not give %s players a smoke grenade.' % weapon)
                cvar.options.append(
                    '1 = Give %s players a smoke grenade.' % weapon)
                cvar.default = 0
                cvar.text = ('If enabled, %s ' % weapon +
                    'players will be given a smoke grenade.')

            # Create the weapon's "flash" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_flash' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL FLASH' % weapon.upper()
                cvar.description.append('If enabled, %s ' % weapon +
                    'players will be given a flashbang.')
                cvar.options.append(
                    '0 = Do not give %s players a flashbang.' % weapon)
                cvar.options.append(
                    '1 = Give %s players a flashbang.' % weapon)
                cvar.default = 0
                cvar.text = ('If enabled, %s ' % weapon +
                    'players will be given a flashbang.')

            # Create the weapon's "health" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_health' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL HEALTH' % weapon.upper()
                cvar.description.append('If enabled, %s players ' % weapon +
                    'will have their health set to the given value.')
                cvar.options.append(
                    "0 = Do not set %s player's health." % weapon)
                cvar.options.append(
                    "1 = Set %s player's health." % weapon)
                cvar.default = 0
                cvar.text = ('If enabled, %s players ' % weapon +
                    'will have their health set to the given value.')

            # Create the weapon's "gravity" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_gravity' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL gravity' % weapon.upper()
                cvar.description.append('If enabled, %s players ' % weapon +
                    'will have their gravity set to the given value.')
                cvar.options.append(
                    "0 = Do not set %s player's gravity." % weapon)
                cvar.options.append(
                    "# = Set %s player's gravity to the " % weapon +
                    "given value times the server's default value.")
                cvar.examples.append(
                    "If the server's gravity is 800, and %s " % cvar.cvarname +
                    "is set to 1.5, the player's gravity will be 1200")
                cvar.default = 0
                cvar.text = ('If enabled, %s players ' % weapon +
                    'will have their gravity set to the given value.')

            # Create the weapon's "speed" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_speed' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL speed' % weapon.upper()
                cvar.description.append('If enabled, %s players ' % weapon +
                    'will have their speed set to the given value.')
                cvar.options.append(
                    "0 = Do not set %s player's speed." % weapon)
                cvar.options.append(
                    "1 = Set %s player's speed." % weapon)
                cvar.default = 0
                cvar.text = ('If enabled, %s players ' % weapon +
                    'will have their speed set to the given value.')

            # Create the weapon's "color" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_color' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL color' % weapon.upper()
                cvar.description.append('If enabled, %s players ' % weapon +
                    'will have their color set to the rgba values.')
                cvar.options.append(
                    "0 = Do not set %s player's color." % weapon)
                cvar.options.append(
                    "1 = Set %s player's color." % weapon)
                cvar.default = 0
                cvar.text = ('If enabled, %s players ' % weapon +
                    'will have their color set to the rgba value.')

            # Create the weapon's "red" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_red' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL RED' % weapon.upper()
                cvar.description.append('Set to the red value '
                    "to use for %s players' color." % weapon)
                cvar.notes.append('Requires '
                    'gg_knifenade_%s_color be set to 1.' % weapon.lower())
                cvar.options.append('# = The red rgba value '
                    'to use for %s players color.' % weapon)
                cvar.default = 255
                cvar.text = ('The red rgba value to use '
                    "for %s players' color." % weapon)

            # Create the weapon's "green" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_green' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL GREEN' % weapon.upper()
                cvar.description.append('Set to the green value '
                    "to use for %s players' color." % weapon)
                cvar.notes.append('Requires '
                    'gg_knifenade_%s_color be set to 1.' % weapon.lower())
                cvar.options.append('# = The green rgba value '
                    'to use for %s players color.' % weapon)
                cvar.default = 255
                cvar.text = ('The green rgba value to use '
                    "for %s players' color." % weapon)

            # Create the weapon's "blue" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_blue' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL BLUE' % weapon.upper()
                cvar.description.append('Set to the blue value '
                    "to use for %s players' color." % weapon)
                cvar.notes.append('Requires '
                    'gg_knifenade_%s_color be set to 1.' % weapon.lower())
                cvar.options.append('# = The blue rgba value '
                    'to use for %s players color.' % weapon)
                cvar.default = 255
                cvar.text = ('The blue rgba value to use '
                    "for %s players' color." % weapon)

            # Create the weapon's "alpha" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_alpha' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL ALPHA' % weapon.upper()
                cvar.description.append('Set to the alpha value '
                    "to use for %s players' color." % weapon)
                cvar.notes.append('Requires '
                    'gg_knifenade_%s_color be set to 1.' % weapon.lower())
                cvar.options.append('# = The alpha rgba value '
                    'to use for %s players color.' % weapon)
                cvar.default = 255
                cvar.text = ('The alpha rgba value to use '
                    "for %s players' color." % weapon)

            # Create the weapon's "emit_sparks" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_emit_sparks' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL EMIT SPARKS' % weapon.upper()
                cvar.description.append(
                    'If enabled, %s players will emit sparks.' % weapon)
                cvar.options.append(
                    '0 = %s players do not emit sparks.' % weapon)
                cvar.options.append('1 = %s players emit sparks.' % weapon)
                cvar.default = 0
                cvar.text = 'If enabled, %s players will emit sparks.' % weapon

            # Create the weapon's "emit_smoke" instance
            with config.cfg_cvar(
              'gg_knifenade_%s_emit_smoke' % weapon.lower()) as cvar:

                cvar.name = '%s LEVEL EMIT SMOKE' % weapon.upper()
                cvar.description.append(
                    'If enabled, %s players will emit smoke.' % weapon)
                cvar.options.append(
                    '0 = %s players do not emit smoke.' % weapon)
                cvar.options.append('1 = %s players emit smoke.' % weapon)
                cvar.default = 0
                cvar.text = 'If enabled, %s players will emit smoke.' % weapon
