# ../scripts/custom/gg_knifenade/modules/bonuses.py

# =============================================================================
# >> IMPORTS
# =============================================================================
# GunGame Imports
#   Players
from gungame51.core.players.shortcuts import Player

# Script Imports
from players import BonusPlayers


# =============================================================================
# >> CLASSES
# =============================================================================
class _KnifeNadeBonuses(dict):
    '''Dictionary class that store hegrenade/knife players'''

    def __init__(self):
        '''Called when the class instance is first initialized'''

        # Store hegrenade/knife as the items in the dictionary
        self['hegrenade'] = BonusPlayers('hegrenade')
        self['knife'] = BonusPlayers('knife')

    def clear(self):
        '''Called when the bonuses should be cleared'''

        # Loop through all weapons in the dictionary
        for weapon in self:

            # Clear the weapon's set of userids
            self[weapon].clear()

    def check_bonuses(self, userid):
        '''Checks if the given player needs to be added
            to one of the items in the dictionary'''

        # Typecast the given userid
        userid = int(userid)

        # Get the Player instance
        player = Player(userid)

        # Does the player need added to one of the items in the dictionary?
        if player.weapon in self and not userid in self[player.weapon]:

            # Add the player to the item's set
            self[player.weapon].add(userid)

    def check_spawn_bonuses(self, userid):
        '''
            Checks to see if the spawning player needs to be given any bonuses
        '''

        # Typecast the given userid
        userid = int(userid)

        # Get the Player instance
        player = Player(userid)

        # Is the player's weapon an item in the dictionary?
        if not player.weapon in self:

            # If not, simply return
            return

        # Is the player's userid in the weapon's set?
        if not userid in self[player.weapon]:

            # If not, add the player's userid to the weapon's set
            self[player.weapon].add(userid)

        # Otherwise
        else:

            # Simply give the player their bonuses
            self[player.weapon].give_player_bonuses(userid)

    def check_remove_bonuses(self, userid):
        '''Checks to see if the given player needs to be
            removed from one of the items in the dictionary'''

        # Typecast the given userid
        userid = int(userid)

        # Get the Player instance
        player = Player(userid)

        # Loop through the weapons in the dictionary
        for weapon in self:

            # Is the player in the current weapon's set and should not be?
            if userid in self[weapon] and player.weapon != weapon:

                # Remove the player from the current weapon's set
                self[weapon].remove(userid)

# Get the _KnifeNadeBonuses instance
knifenade = _KnifeNadeBonuses()
