# ../scripts/custom/gg_knifenade/modules/gravity.py

# =============================================================================
# >> IMPORTS
# =============================================================================
# EventScripts Imports
#   ES
from es import getplayerprop
from es import getuserid
from es import InsertServerCommand
#   Gamethread
from gamethread import cancelDelayed
from gamethread import delayedname


# =============================================================================
# >> CLASSES
# =============================================================================
class _GravityManager(dict):
    '''Class used to manage player gravity amounts'''

    def __setitem__(self, userid, value):
        '''Method used to add a player to the dictionary'''

        # Typecast the given userid
        userid = int(userid)

        # Is the userid already in the dictionary?
        if userid in self:

            # If so, return
            return

        # Store whether the loop is active
        active = bool(self)

        # Store the player's properties
        value = _PlayerProperties(userid, value)

        # Add the player to the dictionary
        super(_GravityManager, self).__setitem__(userid, value)

        # Set the player's gravity
        self.set_gravity(userid)

        # Is the loop already active?
        if not active:

            # If not, start the loop
            self.gravity_loop()

    def __contains__(self, userid):
        '''Method used to determine if a player is in the dictionary'''

        # Typecast the given userid
        userid = int(userid)

        # Return whether the given userid is in the dictionary
        return super(_GravityManager, self).__contains__(userid)

    def __delitem__(self, userid):
        '''Method used to remove the given userid from the dictionary'''

        # Typecast the given userid
        userid = int(userid)

        # Is the userid in the dictionary?
        if not userid in self:

            # If not, no need to remove them
            return

        # Set the player's gravity back to default
        self.set_gravity(userid, 1)

        # Remove the player from the dictionary
        super(_GravityManager, self).__delitem__(userid)

        # Are there anymore players in the dictionary?
        if not self:

            # If not, stop the loop
            cancelDelayed('gg_knifenade_gravity')

    def clear(self):
        '''Method used to remove all players from the dictionary'''

        # Loop through all players in the dictionary
        for userid in list(self):

            # Remove the player from the dictionary
            del self[userid]

    def gravity_loop(self):
        '''Method used to loop through all players in
            the dictionary and set their gravity if needed'''

        # Are there any userids in the dictionary?
        if not self:

            # If not, stop the loop
            return

        # Loop through all players in the dictionary
        for userid in list(self):

            # Does the current userid exist?
            if not getuserid(userid):

                # If not, remove the userid from the dictionary
                del self[userid]

                # Continue to the next userid
                continue

            # Get the player's current flags
            flags = getplayerprop(userid, 'CBasePlayer.m_fFlags')

            # Get the player's current movetype
            movetype = getplayerprop(userid, 'CBasePlayer.movetype')

            # Did the player's movetype or flags change?
            if (self[userid].flags != flags
              or self[userid].movetype != movetype):

                # If so, reset the player's gravity
                self.set_gravity(userid)

        # Use a small delay to continue the loop
        delayedname(.25, 'gg_knifenade_gravity', self.gravity_loop)

    def set_gravity(self, userid, value=None):
        '''Method used to set a player's gravity'''

        # Was a value given?
        if value is None:

            # If not, get the player's gravity value
            value = self[userid].gravity

        # Set the player's gravity
        InsertServerCommand(
            'es_xfire %s !self AddOutput "gravity %s" 0.1 1' % (userid, value))

# Get the _GravityManager instance
gravity = _GravityManager()


class _PlayerProperties(object):
    '''Class used to store values for the given userid'''

    def __init__(self, userid, value):
        '''Called when the class is initialized'''

        # Store the player's gravity amount
        self.gravity = value

        # Store the player's needed properties
        self.flags = getplayerprop(userid, 'CBasePlayer.m_fFlags')
        self.movetype = getplayerprop(userid, 'CBasePlayer.movetype')
