# ../scripts/custom/gg_knifenade/modules/players.py

# =============================================================================
# >> IMPORTS
# =============================================================================
# EventScripts Import
#   ES
from es import ServerVar
#   Playerlib
from playerlib import getPlayer

# SPE Imports
from spe import dropWeapon
from spe import giveNamedItem
from spe import ownsWeapon
from spe import removeEntityByInstance

# Script Imports
from gravity import gravity
from smoke import smoke
from sparks import sparks


# =============================================================================
# >> CLASSES
# =============================================================================
class BonusPlayers(set):
    def __init__(self, weapon):
        '''Called when an instance is first initialized'''

        # Set the instance attributes
        self.weapon = weapon
        for item in ('smoke', 'flash', 'health', 'gravity', 'speed', 'color',
          'red', 'green', 'blue', 'alpha', 'emit_sparks', 'emit_smoke'):
            self.__setattr__(item, ServerVar(
                'gg_knifenade_%s_%s' % (self.weapon, item)))

    def add(self, userid):
        '''Called when a player is added to the set'''

        # Add the player to the set
        super(BonusPlayers, self).add(userid)

        # Give the player their bonuses
        self.give_player_bonuses(userid)

    def remove(self, userid):
        '''Called when a player is removed from the set'''

        # Remove the player's bonuses
        self.remove_player_bonuses(userid)

        # Remove the player from the set
        self.discard(userid)

    def clear(self):
        '''Called when the instance is being cleared'''

        # Loop through each player in the set
        for userid in list(self): 

            # Remove the player from the set and remove their bonuses
            self.remove(userid)

    def give_player_bonuses(self, userid):
        '''Gives the given player their bonuses'''

        # Get the player's playerlib.Player instance
        player = getPlayer(userid)

        # Is the player alive?
        if player.isdead:

            # If not, simply return
            return

        # Should the player have a smoke grenade?
        if self.smoke:

            # Does the player have a smoke grenade?
            if not ownsWeapon(userid, 'weapon_smokegrenade'):

                # If not, give them one
                giveNamedItem(userid, 'weapon_smokegrenade')

        # Should the player have a flashbang?
        if self.flash:

            # Does the player have a flashbang?
            if not ownsWeapon(userid, 'weapon_flashbang'):

                # If not, give them one
                giveNamedItem(userid, 'weapon_flashbang')

        # Does the player's health need set?
        if self.health:

            # Set the player's health
            player.health = self.health

        # Does the player need their gravity modified?
        if self.gravity:

            # Add the player to the gravity list
            gravity[userid] = float(self.gravity)

        # Does the player need their speed set?
        if self.speed:

            # Set the player's speed
            player.speed = self.speed

        # Does the player need their color changed?
        if self.color:

            # Set the player's color
            player.setColor(self.red, self.green, self.blue, self.alpha)


        # Should the player be emitting sparks?
        if self.emit_sparks:

            # Give the player a sparks trail
            sparks[userid] = giveNamedItem(userid, 'env_spark')

        # Should the player be emitting smoke?
        if self.emit_smoke:

            # Give the player a smoke trail
            smoke[userid] = giveNamedItem(userid, 'env_smokestack')

    def remove_player_bonuses(self, userid):
        '''Removes bonuses from the given player'''

        # Get the player's playerlib.Player instance
        player = getPlayer(userid)

        # Should the player have had a smoke grenade?
        if self.smoke:

            # Get the player's weapon_smokegrenade instance, if they own one
            weapon = ownsWeapon(userid, 'weapon_smokegrenade')

            # Does the player have a smoke grenade?
            if weapon:

                # Make the player drop the smoke grenade
                dropWeapon(userid, 'weapon_smokegrenade')

                # Remove the weapon from the game
                removeEntityByInstance(weapon)

        # Should the player have had a flashbang?
        if self.flash:

            # Get the player's weapon_flashbang instance, if they own one
            weapon = ownsWeapon(userid, 'weapon_flashbang')

            # Does the player have a flashbang?
            if weapon:

                # Make the player drop the flashbang
                dropWeapon(userid, 'weapon_flashbang')

                # Remove the weapon from the game
                removeEntityByInstance(weapon)

        # Was the player's health set?
        if self.health:

            # Remove health from the player
            player.health = max(1, player.health - self.health)

        # Was the player's gravity modified?
        if userid in gravity:

            # Remove the player from the gravity list
            del gravity[userid]

        # Did the player have their speed set?
        if self.speed:

            # Reset the player's speed
            player.speed = 1

        # Did the player have their color changed?
        if self.color:

            # Reset the player's color
            player.setColor(255, 255, 255, 255)

        # Was the player emitting sparks?
        if userid in sparks:

            # Remove the sparks from the player
            del sparks[userid]

        # Was the player emitting smoke?
        if userid in smoke:

            # Remove the smoke from the player
            del smoke[userid]
