# ../scripts/custom/gg_knifenade/modules/smoke.py

# =============================================================================
# >> IMPORTS
# =============================================================================
# EventScripts Imports
#   ES
from es import entitysetvalue
from es import InsertServerCommand
from es import precachemodel

# SPE Imports
from spe import getIndexOfEntity
from spe import removeEntityByInstance


# =============================================================================
# >> CLASSES
# =============================================================================
class _SmokePlayers(dict):
    '''Class used to store players and their smoke entity'''

    def __init__(self):
        '''Called when the class is first initialized'''

        # Precache the smoke material model
        self.refresh_precache()

    def __setitem__(self, userid, entity):
        '''Method used to add a player to the dictionary'''

        # Typecast the given userid
        userid = int(userid)

        # Is the userid already in the dictionary?
        if userid in self:

            # If so, return
            return

        # Get the given entity's index
        index = getIndexOfEntity(entity)

        # Set the entity's targetname
        entitysetvalue(index, 'targetname', entity)

        # Give the player smoke
        InsertServerCommand(
            'es_xfire %s %s SetParent !activator;' % (userid, entity) +
            'es_xfire %s %s  AddOutput "BaseSpread 40";' % (userid, entity) +
            'es_xfire %s %s  AddOutput "SpreadSpeed 10";' % (userid, entity) +
            'es_xfire %s %s  AddOutput "Speed 80";' % (userid, entity) +
            'es_xfire %s %s  AddOutput "StartSize 30";' % (userid, entity) +
            'es_xfire %s %s  AddOutput "EndSize 20";' % (userid, entity) +
            'es_xfire %s %s  AddOutput "Rate 15";' % (userid, entity) +
            'es_xfire %s %s  AddOutput "JetLength 75";' % (userid, entity) +
            'es_xfire %s %s  AddOutput "Twist 1";' % (userid, entity) +
            'es_xfire %s %s  AddOutput "SmokeMaterial %s";' % (
                userid, entity, self.model) +
            'es_xfire %s %s  AddOutput "rendercolor 88 88 88";' % (
                userid, entity) +
            'es_xfire %s %s  AddOutput "renderamt 180";' % (userid, entity) +
            'es_xfire %s %s  TurnOn;' % (userid, entity))

        # Add the player to the dictionary
        super(_SmokePlayers, self).__setitem__(entity)

    def __delitem__(self, userid):
        '''Method used to remove the given userid from the dictionary'''

        # Typecast the given userid
        userid = int(userid)

        # Is the userid in the dictionary?
        if not userid in self:

            # If not, no need to remove them
            return

        # Get the player's smoke entity
        entity = self[userid]

        # Turn the smoke off
        InsertServerCommand('es_xfire %s %s TurnOff' % (userid, entity))

        # Remove the smoke
        removeEntityByInstance(entity)

        # Remove the player from the dictionary
        super(_SmokePlayers, self).__delitem__(userid)

    def clear(self):
        '''Method used to remove all players from the dictionary'''

        # Loop through all players in the dictionary
        for userid in list(self):

            # Remove the player from the dictionary
            del self[userid]

    def refresh_precache(self):
        '''Method used to precache the smoke material model'''

        # Store the precached smoke material model
        self.model = precachemodel('particle/particle_smokegrenade1.vmt')

# Get the _SmokePlayers instance
smoke = _SmokePlayers()
